﻿#region Using Directives

using System;
using System.Data.SqlServerCe;
using System.IO;
using System.Configuration;
using CreateSqlCe.Properties;

#endregion

namespace CreateSqlCe
{
    class Program
    {
        /// <summary>
        /// Application Entrypoint
        /// </summary>
        /// <param name="args"></param>
        static void Main(string[] args)
        {
            VerifyDatabase();
        }
        
        /// <summary>
        /// Create a missing SQL CE Database
        /// </summary>
        /// <param name="connectionString"></param>
        public static void VerifyDatabase()
        {
            // Use a SqlCeConnection to obtain the location of the database file
            // Obtain the connection string from the app settings
            
            string connectionString = 
                ConfigurationManager.ConnectionStrings["FileCatalogConnectionString"].ConnectionString;
            
            using (SqlCeConnection localConnection = new SqlCeConnection(connectionString))
            {
                // The SqlCeConnection.Database contains the file path portion
                // of the database from the full connectionstring

                if(!File.Exists(localConnection.Database))
                {
                    // No file, no database!
                    
                    using (SqlCeEngine sqlCeEngine = new SqlCeEngine(connectionString))
                    {
                        sqlCeEngine.CreateDatabase();  // this is really nice :)
                        
                        // Grab the T-SQL out of the embedded resource and split by the GO keyword
                        
                        string[] commands = Resources.CreateObjects.Split(new string[] { "GO" }, 
                            StringSplitOptions.RemoveEmptyEntries);

                        SqlCeCommand sqlCommand = new SqlCeCommand();
                        sqlCommand.Connection = localConnection;
                        
                        // Open connection and execute each statement
                        localConnection.Open();

                        foreach (string command in commands)
                        {
                            sqlCommand.CommandText = command;
                            sqlCommand.ExecuteNonQuery();
                        }
                    }
                }
            }
        }
    }
}
